pub async fn evaluate(value: Value, args: &[Value]) -> BuiltinResult<FindEval>Expand description
Evaluate find and return an object that can materialise the various outputs.
pub async fn evaluate(value: Value, args: &[Value]) -> BuiltinResult<FindEval>Evaluate find and return an object that can materialise the various outputs.