pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<IntersectEvaluation>Expand description
Evaluate the intersect builtin once and expose all outputs.
pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<IntersectEvaluation>Evaluate the intersect builtin once and expose all outputs.