pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<SetdiffEvaluation>Expand description
Evaluate the setdiff builtin once and expose all outputs.
pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<SetdiffEvaluation>Evaluate the setdiff builtin once and expose all outputs.