pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<SortEvaluation>Expand description
Evaluate the sort builtin once and expose both outputs.
pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<SortEvaluation>Evaluate the sort builtin once and expose both outputs.