pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<SortRowsEvaluation>Expand description
Evaluate the sortrows builtin once and expose both outputs.
pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<SortRowsEvaluation>Evaluate the sortrows builtin once and expose both outputs.