pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<UnionEvaluation>Expand description
Evaluate the union builtin once and expose all outputs.
pub async fn evaluate(
a: Value,
b: Value,
rest: &[Value],
) -> BuiltinResult<UnionEvaluation>Evaluate the union builtin once and expose all outputs.