pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<UniqueEvaluation>Expand description
Evaluate unique once and expose all outputs to the caller.
pub async fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<UniqueEvaluation>Evaluate unique once and expose all outputs to the caller.