Module close

Module close 

Canonical close builtin dispatcher.

This module owns the single runtime registration for close and routes requests to plotting or networking close handlers.

Constants

CLOSE_DESCRIPTOR

Functions

close_builtin