pub fn extract_format_string(
value: &Value,
context: &str,
) -> BuiltinResult<String>Expand description
Extract a printf-style format string from a MATLAB value, validating that it is a character row vector or string scalar.
pub fn extract_format_string(
value: &Value,
context: &str,
) -> BuiltinResult<String>Extract a printf-style format string from a MATLAB value, validating that it is a character row vector or string scalar.