Module shape

Module shape 

Functions

canonical_scalar_shape
Return the canonical scalar shape.
dims_to_row_tensor
Convert a dimension vector into a 1×N tensor encoded as f64.
is_scalar_shape
Return true if a shape should be treated as a scalar.
normalize_scalar_shape
Normalize scalar-like shapes to the canonical scalar shape.
value_dimensions
Return the MATLAB-visible dimension vector for a runtime value.
value_ndims
Compute the dimensionality (NDIMS) of a runtime value, with MATLAB semantics.
value_numel
Compute the total number of elements contained in a runtime value.