pub async fn evaluate(args: &[Value]) -> BuiltinResult<FprintfEval>Expand description
Evaluate the fprintf builtin without going through the dispatcher.
pub async fn evaluate(args: &[Value]) -> BuiltinResult<FprintfEval>Evaluate the fprintf builtin without going through the dispatcher.