pub async fn evaluate(
fid_value: &Value,
data_value: &Value,
rest: &[Value],
) -> BuiltinResult<FwriteEval>Expand description
Evaluate the fwrite builtin without invoking the runtime dispatcher.
pub async fn evaluate(
fid_value: &Value,
data_value: &Value,
rest: &[Value],
) -> BuiltinResult<FwriteEval>Evaluate the fwrite builtin without invoking the runtime dispatcher.