try_integer_comparison

Function try_integer_comparison 

pub fn try_integer_comparison(
    lhs: &Value,
    rhs: &Value,
    operation: IntegerComparisonOp,
) -> Result<Option<Value>, IntegerComparisonError>
Performs a comparison when native integer storage is compared against other native integer storage or real numeric storage. This keeps integer values exact even when the other operand is an f64 array.