pub async fn evaluate_max(
value: Value,
rest: &[Value],
) -> BuiltinResult<MaxEvaluation>Expand description
Evaluate the builtin once and expose both outputs (value + indices).
pub async fn evaluate_max(
value: Value,
rest: &[Value],
) -> BuiltinResult<MaxEvaluation>Evaluate the builtin once and expose both outputs (value + indices).