Module hist

Module hist 

MATLAB-compatible hist builtin.

Structs

HistEvaluation
Captures the evaluated histogram so both the renderer and MATLAB outputs share the same data.

Constants

FUSION_SPEC
GPU_SPEC

Functions

evaluate_async
Evaluate the histogram inputs once so renderers and MATLAB outputs share the same data.
hist_builtin