pub async fn evaluate_async(
data: Value,
rest: &[Value],
) -> BuiltinResult<HistEvaluation>Expand description
Evaluate the histogram inputs once so renderers and MATLAB outputs share the same data.
pub async fn evaluate_async(
data: Value,
rest: &[Value],
) -> BuiltinResult<HistEvaluation>Evaluate the histogram inputs once so renderers and MATLAB outputs share the same data.