Module ml

Module ml 

Statistics and Machine Learning Toolbox modeling builtins.

Modules

bayesopt
Deterministic MATLAB-compatible bayesopt surface for small in-memory workflows.
classification
Discriminant classification compatibility surface.
classification_linear
Linear classification model compatibility surface.
classification_tree
Numeric classification tree compatibility surface.
confusionmat
Confusion matrix compatibility surface.
crossvalind
MATLAB-compatible crossvalind builtin.
cvpartition
Cross-validation partition helpers for Statistics and Machine Learning workflows.
distance
Pairwise distance and squareform helpers for Statistics and Machine Learning workflows.
kmeans
k-means clustering compatibility surface.
lasso
Lasso and elastic-net regularized linear regression.
lassoglm
Lasso and elastic-net regularized generalized linear models.
linear_model
Linear regression model compatibility surface.
linkage
Hierarchical agglomerative clustering compatibility surface.
lscov
Linear least-squares with observation covariance weighting.
mnrfit
Multinomial logistic regression compatibility helper.
optimizable_variable
MATLAB-compatible optimizableVariable metadata constructor.
perfcurve
Classification performance curve compatibility surface.
predict
Generic model prediction dispatcher.
regress
Multiple linear regression compatibility surface.
ridge
Ridge regression compatibility surface.
tsne
t-SNE dimensionality reduction compatibility surface.