pub fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<OrderFieldsEvaluation>Expand description
Evaluate the orderfields builtin once and expose both outputs.
pub fn evaluate(
value: Value,
rest: &[Value],
) -> BuiltinResult<OrderFieldsEvaluation>Evaluate the orderfields builtin once and expose both outputs.