Module condition

Module condition 

Executor-neutral condition conversion.

Bytecode, native, and browser executors must agree on which runtime values are valid scalar conditions and how accelerator-backed values are gathered.

Functions

logical_truth_from_value
Convert a runtime value to the scalar truth value required by control flow.