pub fn append_thread_buffer(entries: impl IntoIterator<Item = ConsoleEntry>)Expand description
Append console entries captured on another execution thread without forwarding them again to live stream listeners.
pub fn append_thread_buffer(entries: impl IntoIterator<Item = ConsoleEntry>)Append console entries captured on another execution thread without forwarding them again to live stream listeners.