pub fn record_console_line(stream: ConsoleStream, text: impl Into<String>)Expand description
Record a line-oriented console entry, ensuring the stream text ends with a newline.
pub fn record_console_line(stream: ConsoleStream, text: impl Into<String>)Record a line-oriented console entry, ensuring the stream text ends with a newline.