pub fn record_console_output(stream: ConsoleStream, text: impl Into<String>)Expand description
Record console output for the current thread while also forwarding it to any registered listener (used by wasm bindings for live streaming).
pub fn record_console_output(stream: ConsoleStream, text: impl Into<String>)Record console output for the current thread while also forwarding it to any registered listener (used by wasm bindings for live streaming).