Module interaction

Module interaction 

Structs

AsyncHandlerGuard
EvalHookGuard
RAII guard that restores the previous eval hook on drop.
InteractionPromptOwned

Enums

InteractionKind
Narrow set of interaction kinds used for host I/O hooks.
InteractionResponse

Functions

current_eval_hook
Return the currently installed eval hook, if any.
default_read_line
default_wait_for_key
push_queued_response
replace_async_handler
replace_eval_hook
Replace the global eval hook for the duration of the returned guard’s lifetime. Mirrors the pattern used by replace_async_handler.
request_line_async
wait_for_key_async

Type Aliases

AsyncInteractionFuture
AsyncInteractionHandler
EvalHookFn
Function signature for the eval hook.
EvalHookFuture
Future returned by the eval hook.