pub fn record_recent_figures(handles: impl IntoIterator<Item = u32>)Expand description
Record raw figure handles that were touched on another execution thread.
pub fn record_recent_figures(handles: impl IntoIterator<Item = u32>)Record raw figure handles that were touched on another execution thread.