Functions
- canonical_
scalar_ shape - Return the canonical scalar shape.
- dims_
to_ row_ tensor - Convert a dimension vector into a 1×N tensor encoded as
f64. - is_
scalar_ shape - Return true if a shape should be treated as a scalar.
- normalize_
scalar_ shape - Normalize scalar-like shapes to the canonical scalar shape.
- value_
dimensions - Return the MATLAB-visible dimension vector for a runtime value.
- value_
ndims - Compute the dimensionality (NDIMS) of a runtime value, with MATLAB semantics.
- value_
numel - Compute the total number of elements contained in a runtime value.