Functions
- binary_
numeric_ tensors - Align two numeric tensors for a binary element-wise operation with scalar broadcasting.
- default_
shape_ for - Return a canonical 2-D shape for a tensor given its shape slice and element count.
- dimension_
from_ value_ async - Attempt to parse a dimension index from a scalar-like runtime value.
- dims_
from_ value_ async - Attempt to parse a dimension vector from a runtime value asynchronously.
- element_
count - Return the total number of elements for a given shape.
- is_
scalar_ tensor - Return true when a tensor contains exactly one scalar element.
- logical_
to_ tensor - Convert a logical array (0/1 bytes) into a numeric tensor.
- ones
- Construct an one-filled tensor with the provided shape.
- ones_
with_ dtype - Construct a one-filled tensor with an explicit dtype flag.
- parse_
dimension - Convert an argument into a dimension index (1-based) if possible.
- scalar_
f64_ from_ value_ async - Attempt to extract a scalar f64 from a runtime value asynchronously.
- tensor_
into_ value - Convert a
Tensorback into a runtime value. - value_
into_ tensor - Convert a
Valueinto an ownedTensor, defaulting error messages to"sum". - value_
into_ tensor_ for - Convert a
Valueinto a tensor while customising the builtin name in error messages. - value_
to_ string - Attempt to extract a string from a runtime value.
- value_
to_ tensor - Clone a
Valueand coerce it into a tensor. - zeros
- Construct a zero-filled tensor with the provided shape.
- zeros_
with_ dtype - Construct a zero-filled tensor with an explicit dtype flag.