Skip to main contentModule workspace
Source - WorkspaceResolver
- assign
- clear
- global_names
- Return the list of global variable names visible to the active workspace.
- is_available
- Returns true when a resolver has been registered.
- lookup
- Lookup a variable by name in the active workspace.
- register_workspace_resolver
- Register the workspace resolver. Ignition installs this once during
initialization so that language builtins can query variables lazily.
- remove
- snapshot
- Snapshot the active workspace into a vector of
(name, value) pairs.
Returns None when no resolver/workspace is active.